@@ -15,7 +15,7 @@ For more information about candles see :term:`candle` in glossary.
 
 import datetime
 from dataclasses import dataclass
-from typing import List, Optional, Tuple, TypedDict
+from typing import List, Optional, Tuple, TypedDict, Collection, Iterable
 
 import pandas as pd
 import pyarrow as pa
@@ -467,7 +467,10 @@ class GroupedCandleUniverse(PairGroupedUniverse):
         raise CandleSampleUnavailable(
             f"Could not find any candles for pair {pair_id}, value kind '{kind}', between {when} - {last_allowed_timestamp}\n"
             f"The pair has {len(samples_per_kind)} candles between {first_sample['timestamp']} - {last_sample['timestamp']}\n"
-            f"Sample interval is {second_sample['timestamp'] - first_sample['timestamp']}"
+            f"Sample interval is {second_sample['timestamp'] - first_sample['timestamp']}\n"
+            f"\n"
+            f"This is usually due to sparse candle data - trades have not been made or the blockchain was halted during the price look-up period.\n"
+            f"Try to increase look back perid in your code."
             )
 
 
@@ -492,7 +495,20 @@ class GroupedCandleUniverse(PairGroupedUniverse):
         """
         return GroupedCandleUniverse(df)
 
+    @staticmethod
+    def create_from_multiple_candle_datafarames(dfs: Iterable[pd.DataFrame]) -> "GroupedCandleUniverse":
+        """Construct universe based on multiple trading pairs.
 
+        Useful for synthetic data/testing.
+
+        :param dfs:
+            List of dataframes/series where each trading pair is as isolated
+            OHLCV data feed.
+        """
+        merged = pd.concat(dfs)
+        return GroupedCandleUniverse(merged)
+
+\
 class TradingPairDataAvailability(TypedDict):
     """Trading data avaioilability description for a single pair.
 
