@@ -15,7 +15,7 @@ To download the pairs dataset see
 import logging
 import enum
 from dataclasses import dataclass
-from typing import Optional, List, Iterable, Dict, Union, Set, Tuple
+from typing import Optional, List, Iterable, Dict, Union, Set, Tuple, TypeAlias
 
 import pandas as pd
 import numpy as np
@@ -44,6 +44,20 @@ class DuplicatePair(Exception):
     """Found multiple trading pairs for the same naive lookup."""
 
 
+
+#: Shorthand method to identify trading pairs when written down by a human.
+#:
+#: This is `(chain, exchange slug, base token, quote token)`.
+#:
+#: Each major trading pair is identifiable as (chain, exchange, base token, quote token tuple).
+#: Note that because there can be multipe tokens and fake tokens with the same name,
+#: we usually refer to the "best" token which is the highest liquidty/volume trading
+#: pair on the particular exchange.
+#:
+HumanReadableTradingPairDescription: TypeAlias = Tuple[ChainId, str, str, str]
+
+
+
 @dataclass_json
 @dataclass
 class DEXPair:
@@ -239,6 +253,17 @@ class DEXPair:
         chain_name = self.chain_id.get_slug()
         return f"<Pair #{self.pair_id} {self.base_token_symbol} - {self.quote_token_symbol} ({self.address}) at exchange #{self.exchange_id} on {chain_name}>"
 
+    def __eq__(self, other: "DEXPair"):
+        """Trade positions are unique by opening timestamp and pair id.]
+
+        We assume there cannot be a position opened for the same asset at the same time twice.
+        """
+        return self.pair_id == other.pair_id
+
+    def __hash__(self):
+        """set() and dict() compatibility"""
+        return hash(self.pair_id)
+
     @property
     def base_token_address(self) -> str:
         """Get smart contract address for the base token.
@@ -482,12 +507,20 @@ class PandasPairUniverse:
     def get_pair_by_id(self, pair_id: PrimaryKey)  -> Optional[DEXPair]:
         """Look up pair information and return its data.
 
-        :return: Nicely presented :py:class:`DEXPair`.
+        :return:
+            Nicely presented :py:class:`DEXPair`.
+
+            If we do not have an entry for `pair_id`,
+            return None.
         """
 
         if self.pair_map:
             # TODO: Eliminate non-indexed code path?
             data = self.pair_map.get(pair_id)
+
+            if data is None:
+                return None
+
             return DEXPair.from_dict(data)
 
         # TODO: Remove
@@ -649,6 +682,75 @@ class PandasPairUniverse:
 
         return None
 
+    def get_pair_by_human_description(self,
+                                      exchange_universe: ExchangeUniverse,
+                                      desc: HumanReadableTradingPairDescription) -> DEXPair:
+        """Get pair by its human readable description.
+
+        Look up a trading pair by chain, exchange, base, quote token tuple.
+
+        See :py:data:`HumanReadableTradingPairDescription` for more information.
+
+        Example:
+
+        .. code-block::
+
+            # Get BNB-BUSD pair on PancakeSwap v2
+            desc = (ChainId.bsc, "pancakeswap-v2", "WBNB", "BUSD")
+            bnb_busd = pair_universe.get_pair_by_human_description(exchange_universe, desc)
+            assert bnb_busd.base_token_symbol == "WBNB"
+            assert bnb_busd.quote_token_symbol == "BUSD"
+            assert bnb_busd.buy_volume_30d > 1_000_000
+
+        :param exchange_universe:
+            The current database used to decode exchanges.
+
+        :return:
+            The trading pair on the exchange.
+
+            Highest volume trading pair if multiple matches.
+
+        :raise NoPairFound:
+            In the case input data cannot be resolved.
+
+        """
+
+        chain_id, exchange_slug, base_token, quote_token = desc
+
+        assert isinstance(chain_id, ChainId), f"Not ChainId: {chain_id}"
+        assert type(exchange_slug) == str, f"Not exchange slug: {exchange_slug}"
+        assert type(base_token) == str, f"Not base token string: {base_token}"
+        assert type(quote_token) == str, f"Not quote token string: {quote_token}"
+
+        exchange = exchange_universe.get_by_chain_and_slug(chain_id, exchange_slug)
+        if exchange is None:
+            # Try to produce very helpful error message
+            if exchange_universe.get_exchange_count() == 1:
+                exchange_slug = exchange_universe.get_single().exchange_slug
+                exchange_message = f"The slug of the only exchange we have is {exchange_slug}."
+            else:
+                exchange_slug = None
+                exchange_message = ""
+
+            raise NoPairFound(f"The trading universe does not contain data for the exchange {exchange_slug} on chain {chain_id.name}.\n"
+                              f"Did you construct the trading universe correctly?\n"
+                              f"We have data for {exchange_universe.get_exchange_count()} exchange.\n"
+                              f"{exchange_message}")
+
+        pair = self.get_one_pair_from_pandas_universe(
+            exchange.exchange_id,
+            base_token,
+            quote_token,
+            pick_by_highest_vol=True,
+        )
+
+        if pair is None:
+            raise NoPairFound(f"Exchange {exchange_slug} does not have a pair {base_token}-{quote_token}.\n"
+                              f"This might be a problem in your data filtering.?"
+                              f"Did you construct the trading universe correctly?")
+
+        return pair
+
     def create_parquet_load_filter(self, count_limit=10_000) -> List[Tuple]:
         """Returns a Parquet loading filter that contains pairs in this universe.
 
